@@ -22,7 +22,7 @@
 # The Script was developed for the operating systems Solaris, Linux and MacOS.
 
 # The SDK name
-OO_SDK_NAME=libreoffice6.2_sdk
+OO_SDK_NAME=libreoffice25.8_sdk
 export OO_SDK_NAME
 
 # Installation directory of the Software Development Kit.
@@ -54,6 +54,10 @@ OO_SDK_SED_HOME=/usr/bin
 # Example: OO_SDK_CPP_HOME=/usr/bin
 OO_SDK_CPP_HOME=/usr/lib/distcc/bin
 
+# Directory of the .NET SDK.
+# Example: OO_SDK_DOTNET_ROOT=/usr/lib/dotnet
+OO_SDK_DOTNET_ROOT=
+
 # Directory of the Java SDK.
 # Example: OO_SDK_JAVA_HOME=/usr/jdk/jdk1.6.0_10
 OO_SDK_JAVA_HOME=/usr/lib/jvm/default
@@ -200,7 +204,7 @@ esac
 PATH=${OO_SDK_HOME}/bin:${OO_SDK_OUT}/${exampleout}/bin:${OO_SDK_URE_BIN_DIR}:${OFFICE_PROGRAM_PATH}:${PATH}
 
 # Set the classpath
-CLASSPATH=${OO_SDK_URE_JAVA_DIR}/juh.jar:${OO_SDK_URE_JAVA_DIR}/jurt.jar:${OO_SDK_URE_JAVA_DIR}/ridl.jar:${OO_SDK_URE_JAVA_DIR}/unoloader.jar:${OFFICE_HOME}/$sdk_lo_java_dir/unoil.jar:${CLASSPATH}
+CLASSPATH=${OO_SDK_URE_JAVA_DIR}/libreoffice.jar:${OO_SDK_URE_JAVA_DIR}/unoloader.jar:${CLASSPATH}
 export CLASSPATH
 
 
@@ -239,6 +243,13 @@ then
     export OO_SDK_CPP_HOME
 fi
 
+# Add directory of the dotnet command-line tool to the path, if necessary.
+if [ -n "${OO_SDK_DOTNET_ROOT}" ]
+then
+    PATH=${OO_SDK_DOTNET_ROOT}:${PATH}
+    export OO_SDK_DOTNET_ROOT
+fi
+
 # Add directory of the Java tools to the path, if necessary.
 if [ -n "${OO_SDK_JAVA_HOME}" ]
 then
@@ -293,6 +304,7 @@ echo " * Zip = $OO_SDK_ZIP_HOME"
 echo " * cat = $OO_SDK_CAT_HOME"
 echo " * sed = $OO_SDK_SED_HOME"
 echo " * C++ Compiler = $OO_SDK_CPP_HOME"
+echo " * Dotnet = $OO_SDK_DOTNET_ROOT"
 echo " * Java = $OO_SDK_JAVA_HOME"
 echo " * SDK Output directory = $OO_SDK_OUT"
 echo " * Auto deployment = $SDK_AUTO_DEPLOYMENT"
